@@ -1,7 +1,6 @@
 from django.db import models
 from edc_identifier.model_mixins import UniqueSubjectIdentifierFieldMixin
-from edc_model import models as edc_models
-from edc_model.models import HistoricalRecords
+from edc_model.models import BaseUuidModel, HistoricalRecords
 from edc_sites.models import CurrentSiteManager, SiteModelMixin
 from edc_utils import get_utcnow
 from edc_visit_tracking.managers import CrfModelManager
@@ -23,7 +22,7 @@ class LpCsf(
     BiosynexSemiQuantitativeCragMixin,
     QuantitativeCultureModelMixin,
     SiteModelMixin,
-    edc_models.BaseUuidModel,
+    BaseUuidModel,
 ):
 
     report_datetime = models.DateTimeField(default=get_utcnow)
@@ -34,6 +33,6 @@ class LpCsf(
 
     history = HistoricalRecords()
 
-    class Meta(edc_models.BaseUuidModel.Meta):
+    class Meta(BaseUuidModel.Meta):
         verbose_name = "Lumbar Puncture/Cerebrospinal Fluid"
         verbose_name_plural = "Lumbar Puncture/Cerebrospinal Fluid"
